==> jc-1.4.0.tar.gz: gnu/java/beans/editors/ColorEditor.h <==
// public class gnu.java.beans.editors.ColorEditor

// class file dependencies
// @dep_class 3b78fc3cb8354ddf gnu_java_beans_editors_ColorEditor
// @dep_class 5a63ffefcb362768 java_beans_PropertyEditorSupport
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_beans_PropertyEditorSupport

#include "java/beans/PropertyEditorSupport.h"

#ifndef _JC_gnu_java_beans_editors_ColorEditor_H_
#define _JC_gnu_java_beans_editors_ColorEditor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_editors_ColorEditor$sub_refs	_jc_gnu_java_beans_editors_ColorEditor$sub_refs;
typedef struct _jc_gnu_java_beans_editors_ColorEditor$sub_nonrefs	_jc_gnu_java_beans_editors_ColorEditor$sub_nonrefs;
typedef struct _jc_gnu_java_beans_editors_ColorEditor$refs	_jc_gnu_java_beans_editors_ColorEditor$refs;
typedef struct _jc_gnu_java_beans_editors_ColorEditor$nonrefs	_jc_gnu_java_beans_editors_ColorEditor$nonrefs;
typedef struct _jc_gnu_java_beans_editors_ColorEditor$object	_jc_gnu_java_beans_editors_ColorEditor$object;

typedef const struct _jc_gnu_java_beans_editors_ColorEditor$vmethods	_jc_gnu_java_beans_editors_ColorEditor$vmethods;
typedef const struct _jc_gnu_java_beans_editors_ColorEditor$vtable	_jc_gnu_java_beans_editors_ColorEditor$vtable;
typedef const struct _jc_gnu_java_beans_editors_ColorEditor$vtype	_jc_gnu_java_beans_editors_ColorEditor$vtype;

// Constructors
extern void _jc_gnu_java_beans_editors_ColorEditor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_beans_editors_ColorEditor$method$getAsText$e78133031f0dd45a(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *);
extern _jc_object_array *_jc_gnu_java_beans_editors_ColorEditor$method$getTags$1021dc90b8959b76(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *);
extern void _jc_gnu_java_beans_editors_ColorEditor$method$setAsText$3108622962800f9f(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_beans_editors_ColorEditor$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_editors_ColorEditor$method_info$getAsText$e78133031f0dd45a;
extern _jc_method _jc_gnu_java_beans_editors_ColorEditor$method_info$getTags$1021dc90b8959b76;
extern _jc_method _jc_gnu_java_beans_editors_ColorEditor$method_info$setAsText$3108622962800f9f;
extern _jc_method _jc_gnu_java_beans_editors_ColorEditor$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_beans_editors_ColorEditor$vmethods {
	struct _jc_java_lang_String$object	*(*getAsText$e78133031f0dd45a)(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *);
	_jc_object_array	*(*getTags$1021dc90b8959b76)(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *);
	void	(*setAsText$3108622962800f9f)(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *, struct _jc_java_lang_String$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *);
};

// Vtable
struct _jc_gnu_java_beans_editors_ColorEditor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_PropertyEditorSupport$vmethods	java_beans_PropertyEditorSupport;
	_jc_gnu_java_beans_editors_ColorEditor$vmethods	gnu_java_beans_editors_ColorEditor;
};

// Vtype
struct _jc_gnu_java_beans_editors_ColorEditor$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_editors_ColorEditor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_editors_ColorEditor$sub_refs {
	_jc_object_array	*stdColors;
	_jc_object_array	*stdColorNames;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_editors_ColorEditor$refs {
    _jc_gnu_java_beans_editors_ColorEditor$sub_refs	gnu_java_beans_editors_ColorEditor;
    _jc_java_beans_PropertyEditorSupport$sub_refs	java_beans_PropertyEditorSupport;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_editors_ColorEditor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_editors_ColorEditor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_PropertyEditorSupport$sub_nonrefs	java_beans_PropertyEditorSupport;
    _jc_gnu_java_beans_editors_ColorEditor$sub_nonrefs	gnu_java_beans_editors_ColorEditor;
};

// Object instance structure
struct _jc_gnu_java_beans_editors_ColorEditor$object {
	_jc_gnu_java_beans_editors_ColorEditor$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_editors_ColorEditor$vtype	*vtype;
	_jc_gnu_java_beans_editors_ColorEditor$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_editors_ColorEditor$vtype _jc_gnu_java_beans_editors_ColorEditor$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_editors_ColorEditor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_editors_ColorEditor$class_object;

#endif	/* _JC_gnu_java_beans_editors_ColorEditor_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/editors/ColorEditor.h <==
// public class gnu.java.beans.editors.ColorEditor

// class file dependencies
// @dep_class 3b78fc3cb8354ddf gnu_java_beans_editors_ColorEditor
// @dep_class 5a63ffefcb362768 java_beans_PropertyEditorSupport
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_beans_PropertyEditorSupport

#include "java/beans/PropertyEditorSupport.h"

#ifndef _JC_gnu_java_beans_editors_ColorEditor_H_
#define _JC_gnu_java_beans_editors_ColorEditor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_editors_ColorEditor$sub_refs	_jc_gnu_java_beans_editors_ColorEditor$sub_refs;
typedef struct _jc_gnu_java_beans_editors_ColorEditor$sub_nonrefs	_jc_gnu_java_beans_editors_ColorEditor$sub_nonrefs;
typedef struct _jc_gnu_java_beans_editors_ColorEditor$refs	_jc_gnu_java_beans_editors_ColorEditor$refs;
typedef struct _jc_gnu_java_beans_editors_ColorEditor$nonrefs	_jc_gnu_java_beans_editors_ColorEditor$nonrefs;
typedef struct _jc_gnu_java_beans_editors_ColorEditor$object	_jc_gnu_java_beans_editors_ColorEditor$object;

typedef const struct _jc_gnu_java_beans_editors_ColorEditor$vmethods	_jc_gnu_java_beans_editors_ColorEditor$vmethods;
typedef const struct _jc_gnu_java_beans_editors_ColorEditor$vtable	_jc_gnu_java_beans_editors_ColorEditor$vtable;
typedef const struct _jc_gnu_java_beans_editors_ColorEditor$vtype	_jc_gnu_java_beans_editors_ColorEditor$vtype;

// Constructors
extern void _jc_gnu_java_beans_editors_ColorEditor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_beans_editors_ColorEditor$method$getAsText$e78133031f0dd45a(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_gnu_java_beans_editors_ColorEditor$method$getTags$1021dc90b8959b76(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_editors_ColorEditor$method$setAsText$3108622962800f9f(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_editors_ColorEditor$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_editors_ColorEditor$method_info$getAsText$e78133031f0dd45a;
extern _jc_method _jc_gnu_java_beans_editors_ColorEditor$method_info$getTags$1021dc90b8959b76;
extern _jc_method _jc_gnu_java_beans_editors_ColorEditor$method_info$setAsText$3108622962800f9f;
extern _jc_method _jc_gnu_java_beans_editors_ColorEditor$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_beans_editors_ColorEditor$vmethods {
	struct _jc_java_lang_String$object	*(*getAsText$e78133031f0dd45a)(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getTags$1021dc90b8959b76)(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *) _JC_JCNI_ATTR;
	void	(*setAsText$3108622962800f9f)(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_beans_editors_ColorEditor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_editors_ColorEditor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_PropertyEditorSupport$vmethods	java_beans_PropertyEditorSupport;
	_jc_gnu_java_beans_editors_ColorEditor$vmethods	gnu_java_beans_editors_ColorEditor;
};

// Vtype
struct _jc_gnu_java_beans_editors_ColorEditor$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_editors_ColorEditor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_editors_ColorEditor$sub_refs {
	_jc_object_array	*stdColors;
	_jc_object_array	*stdColorNames;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_editors_ColorEditor$refs {
    _jc_gnu_java_beans_editors_ColorEditor$sub_refs	gnu_java_beans_editors_ColorEditor;
    _jc_java_beans_PropertyEditorSupport$sub_refs	java_beans_PropertyEditorSupport;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_editors_ColorEditor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_editors_ColorEditor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_PropertyEditorSupport$sub_nonrefs	java_beans_PropertyEditorSupport;
    _jc_gnu_java_beans_editors_ColorEditor$sub_nonrefs	gnu_java_beans_editors_ColorEditor;
};

// Object instance structure
struct _jc_gnu_java_beans_editors_ColorEditor$object {
	_jc_gnu_java_beans_editors_ColorEditor$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_editors_ColorEditor$vtype	*vtype;
	_jc_gnu_java_beans_editors_ColorEditor$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_editors_ColorEditor$vtype _jc_gnu_java_beans_editors_ColorEditor$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_editors_ColorEditor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_editors_ColorEditor$class_object;

#endif	/* _JC_gnu_java_beans_editors_ColorEditor_H_ */
